pub enum Decision {
DraftRequiresApproval {
gate: ReviewGate,
},
Rejected {
reason: RejectionReason,
gate: ReviewGate,
},
}Expand description
Customer-copy decision that either remains approval-gated or is rejected for rewrite.
Variants
DraftRequiresApproval
Customer-facing copy is only a draft until the customer-message approval gate is satisfied.
Fields

gate: ReviewGateApproval gate that must be satisfied before recommendation or customer-copy workflow proceeds.
Rejected
Customer-facing copy is rejected because it contains an unsafe claim or unsupported promise.
Fields

reason: RejectionReasonRejection reason staff must address before this copy can be approved.

gate: ReviewGateApproval gate that must be satisfied before recommendation or customer-copy workflow proceeds.